import { reactive, toRefs } from "vue";
import { nianji_list, xueqi_list } from "@/utils/constant.js";
import { onLoad } from "@dcloudio/uni-app";

export function useSelectGrade() {
  const data = reactive({
    activeNianji: null, // 当前年级
    activeXueqi: null, // 当前学期
  });

  onLoad((options) => {
    const { nianji, xueqi } = options;
    data.activeNianji = nianji;
    data.activeXueqi = xueqi;
  });

  // 选择 年级+学期
  function handleConfirm() {
    if (!data.activeNianji) {
      uni.showToast({
        title: "请选择年级",
        duration: 2000,
      });
      return;
    }

    if (!data.activeXueqi) {
      uni.showToast({
        title: "请选择学期",
        duration: 2000,
      });
      return;
    }

    const text1 = nianji_list.find(
      (item) => item.id == data.activeNianji
    ).label;
    const text2 = xueqi_list.find((item) => item.id == data.activeXueqi).label;

    const options = {
      nianji: data.activeNianji,
      xueqi: data.activeXueqi,
      text: text1 + text2,
    };

    goDAOToStudy(options);
  }

  // 跳转 岛 学习
  function goDAOToStudy({ nianji, xueqi, text }) {
    uni.navigateTo({
      url: `/pages/study/index?nianji=${nianji}&xueqi=${xueqi}&text=${text}`,
    });
  }

  return {
    // 变量
    nianji_list,
    xueqi_list,
    ...toRefs(data),

    // 方法
    handleConfirm, // 选择年级+学期
  };
}
